export const firstLetterUpperCase = (str:string):string => {
    const first = str.charAt(0).toUpperCase();
    const rest = str.slice(1);
    return `${first}${rest.toLowerCase()}`;
  };

  export const splitByUnderscore = (str:string):string => {
    const [first, ...array] = str.split("_");
    const firstUpper = firstLetterUpperCase(first);
    return [firstUpper, ...array].join(" ");
  };

  export const reverseNamesInObject = (obj:object, func:(s:string)=>any):object => {
    return Object.keys(obj).reduce((result, item) => {
      result[item] = func(item);
      return result;
    }, {});
  };

  export const languageChoose = (languageObject:object, currentLanguage:string):object => {
    if (!languageObject) {
        window.console.error("No language object!");
      return {};
    }
    if (languageObject[currentLanguage]) {
      return languageObject[currentLanguage];
    } else {
        window.console.error("Invalid language object!");
      return {};
    }
  };

  export const addObjPropLangToObj = (
    {languageObject}: {languageObject:object},
    {defaultLanguage}: {defaultLanguage:string},
    {objectPropertiesLanguage}: {objectPropertiesLanguage:string},
  ):object => {
    const valueOfObjectLanguage = reverseNamesInObject(
      languageObject[defaultLanguage],
      splitByUnderscore
    );
    return Object.assign({}, languageObject, {
      [objectPropertiesLanguage]: valueOfObjectLanguage
    });
  };

  export const differenceFromDefaultLanguage = (
    defaultLanguageObject:object,
    currentLanguageObject:object
  ):void => {
    const differentProperties = Object.keys(defaultLanguageObject).filter(
      e => Object.keys(currentLanguageObject).indexOf(e) === -1
    );
    differentProperties.forEach(e =>
      window.console.warn(`You didnt localize field ${e}`)
    );
  };
  

  export const localizeErrors = (
    languageObject:object,
    isObjectPropertiesLanguage:boolean,
    props:any
  ):boolean => {
    if (!languageObject) {
        window.console.error("No object to localize!");
      return true;
    }
    if (!props.currentLanguage) {
        window.console.error(
        "You need to set current language! You can do that with method setCurrentLanguage(string)!"
      );
      return true;
    }
    if (
      props.objectPropertiesLanguage !== props.currentLanguage &&
      !languageObject[props.currentLanguage]
    ) {
        window.console.error(
        "Current language you set does not exist in localized object! Check your setCurrentLanguage method!"
      );
      return true;
    }
  
    if (!languageObject[props.defaultLanguage]) {
        window.console.error(
        "Default language you set does not exist in localized object! Check your setDefaultLanguage method!"
      );
      return true;
    }
  
    if (
      isObjectPropertiesLanguage &&
      languageObject[props.objectPropertiesLanguage]
    ) {
        window.console.error(
        "Language in object is equal to your object properties language. This is not alowed!"
      );
      return true;
    }
  
    if (isObjectPropertiesLanguage && !props.defaultLanguage) {
      window.console.error(
        "If you want to use object properties language you need to set default language! You can do that with method setDefaultLanguage(string) "
      );
    
    }
    if (isObjectPropertiesLanguage && !props.objectPropertiesLanguage) {
        window.console.error(
        "If you want to use object properties language you need to set object properties language! You can do that with method setObjectPropertiesLanguage(string) "
      );
      
    }
    return false
  };